@@ -190,6 +190,7 @@ public:
 		STATE_LIBRESET,
 		STATE_WAITKEY,
 		STATE_LIBWAIT,
+		STATE_IRESET,
 		STATE_FINAL,
 
 		STATE_STANDBY = STATE_DOWN,
@@ -1676,6 +1677,7 @@ protected:
 	bool stateInitial(Event *event);
 	bool stateFinal(Event *event);
 	bool stateIdle(Event *event);
+	bool stateIdleReset(Event *event);
 	bool stateReset(Event *event);
 	bool stateRelease(Event *event);
 	bool stateBusy(Event *event);
