@@ -187,14 +187,14 @@ BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
 
 	if(!canAccess(path))
 	{
-		server->errlog("access", path);
+		errlog("access", "cannot load %s", path);
 		return NULL;
 	}
 
 	dso = new DSO(path);
 	if(!dso->isValid())
 	{
-		server->errlog("error", dso->getError());
+		errlog("error", "%s: %s", path, dso->getError());
 		return NULL;
 	}
 	return get(id);
