@@ -215,18 +215,50 @@ bool BayonneSession::stateLibreset(Event *event)
 	return enterCommon(event);
 }
 
+bool BayonneSession::stateIdleReset(Event *event)
+{
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		if(thread)
+		{
+			delete thread;
+			thread = NULL;
+		}
+		startTimer(reset_timer);
+		return true;
+	case TIMER_EXPIRED:
+		if(image)
+			detach();
+		setState(STATE_IDLE);
+		return true;
+	case MAKE_IDLE:
+		return true;
+	}
+	return false;
+}
+
 bool BayonneSession::stateReset(Event *event)
 {
+	timeout_t timer;
+
 	if(enterReset(event))
 		return true;
 
 	switch(event->id)
 	{
 	case ENTER_STATE:
-		startTimer(driver->getResetTimer());
+		timer = driver->getResetTimer();
+		if(thread)
+		{
+			delete thread;
+			thread = NULL;
+			if(timer < reset_timer)
+				timer = reset_timer;
+		}
+		startTimer(timer);
 		return true;
 	case TIMER_EXPIRED:
-		slog.error("%s: reset timeout failure", logname);
 	case CALL_RESTART:
 restart:
 		stopTimer();
@@ -235,8 +267,10 @@ restart:
 	case RESTART_FAILED:
 		slog.error("%s: reset failed", logname);
 		goto restart;
+	case MAKE_IDLE:
+		return true;
 	}
-	return true;
+	return false;
 }
 
 bool BayonneSession::stateRelease(Event *event)
@@ -259,8 +293,10 @@ release:
 	case RELEASE_FAILED:
 		slog.error("%s: release failed");
 		goto release;
+	case MAKE_IDLE:
+		return true;
 	}
-	return true;
+	return false;
 }
 
 bool BayonneSession::stateStart(Event *event)
@@ -1072,7 +1108,7 @@ bool BayonneSession::stateJoin(Event *event)
 	rtn = enterCommon(event);
 	if(!isJoined())
 	{
-		clrAudio();
+//		clrAudio();
 		switch(id)
 		{
 		case DTMF_KEYUP:
@@ -1094,7 +1130,7 @@ bool BayonneSession::stateJoin(Event *event)
 	return rtn;
 
 part:
-	clrAudio();
+//	clrAudio();	// get on other side of reset timer
 	if(!scriptEvent(msg))
 		if(!signalScript(SIGNAL_PART))
 			error(emsg);
@@ -1556,6 +1592,8 @@ bool BayonneSession::stateThreading(Event *event)
 
 bool BayonneSession::stateHangup(Event *event) 
 {
+	timeout_t timer;
+
         if(enterHangup(event))
                 return true; 
 
@@ -1576,27 +1614,36 @@ bool BayonneSession::stateHangup(Event *event)
 
 	case LINE_ON_HOOK:
 	case TIMER_EXPIRED:
+		clrAudio();
 		setState(STATE_IDLE);
 		return true;
 	case ENTER_STATE:
 		exiting = true;	// definately exiting...
 		newTid();
 
+		timer = driver->getHangupTimer();
+		if(!offhook)
+			timer = 0;
+
 		if(thread)
+		{
+			if(timer < reset_timer)
+				timer = reset_timer;
 			delete thread;
+			thread = NULL;
+		}
 
 		if(image)
 			detach();
 
-		clrAudio();
-
-		if(!offhook)
+		if(!timer)
 		{
+			clrAudio();
 			setState(STATE_IDLE);
 			return true;
 		}
 		setOffhook(false);
-		startTimer(driver->getHangupTimer());
+		startTimer(timer);
 		return true;
         }
 
@@ -1689,14 +1736,16 @@ bool BayonneSession::enterCommon(Event *event)
 		return true;
 
 	case MAKE_IDLE:
-		if(thread)
-			delete thread;
-
 		if(offhook)
 		{
 			setState(STATE_HANGUP);
 			return true;
 		}
+		if(thread)
+		{
+			setState(STATE_IRESET);
+			return true;
+		}
 		if(image)
 			detach();
 		setState(STATE_IDLE);
