@@ -16,6 +16,7 @@
 
 #include "bayonne.h"
 #include <cc++/slog.h>
+#include <cc++/process.h>
 #include <ccrtp/rtp.h>
 #undef	HAVE_CONFIG_H
 #include <eXosip/eXosip.h>
@@ -30,7 +31,7 @@ class Registry : public ScriptRegistry
 {
 public:
 	const char *uri, *contact, *proxy;
-	const char *interface;
+	const char *iface;
 	const char *hostid;
 	const char *portid;
 	const char *userid;
