@@ -432,18 +432,14 @@ void loadConfig(void)
 		keyengine.load("~bayonne/engine");
 	}
 
-	Process::setGroup(keyserver.getLast("group"));
-	if(getuid())
-		Dir::create(keypaths.getLast("datafiles"));
-	else
-	{
-		umask(002);
-		mkdir(keypaths.getLast("datafiles"), 02775);
-	}
 	umask(007);
+	Process::setGroup(keyserver.getLast("group"));
+	Dir::create(keypaths.getLast("datafiles"));
 	Dir::create(keypaths.getLast("runfiles"));
 	Dir::create(keypaths.getLast("logfiles"));
 
+	keypaths.setValue("home", keypaths.getLast("datafiles"));
+
 	if(!getuid())
 		goto live;
 
@@ -453,6 +449,7 @@ void loadConfig(void)
 		keypaths.setValue("datafiles", homepath);
 	}
 
+	keypaths.setValue("control", keypaths.getLast("runfiles"));
 	if(!canModify(keypaths.getLast("runfiles")))
 	{
 		homed = true;
