@@ -115,6 +115,9 @@ static void loading(void)
 	BayonneTranslator *translator = NULL;
 	static char vlib[64];
 
+	if(!Process::getEnv("SERVER_SYSEXEC"))
+		Process::setEnv("SERVER_SYSEXEC", keypaths.getLast("scripts"), true);
+
 	Process::setEnv("SERVER_PREFIX", keypaths.getLast("datafiles"), true);
         Process::setEnv("SERVER_PROMPTS", keypaths.getLast("prompts"), true);
         Process::setEnv("SERVER_SCRIPTS", keypaths.getLast("scripts"), true);
