@@ -28,6 +28,12 @@
 #define	VERSION "0.3.1"
 #endif
 
+#ifdef	WIN32
+#define	SCRIPT_EXTENSIONS ".bat.cmd.php.py.pl"
+#else
+#define	SCRIPT_EXTENSIONS ".sh.py.pl.php"
+#endif
+
 namespace server {
 using namespace ost;
 using namespace std;
